@@ -15,6 +15,7 @@ import zipfile
 from .common import gethostname, iswindows
 from .trace import TraceProxy
 from .consts import NAME, VERSION
+from unidecode import unidecode
 
 
 def get_variable(job, name, default=None):
@@ -143,6 +144,23 @@ def clean(trace, folder, docker, attempts=10):
         else:
             trace.writeline("Error cleaning after build {}".format(err))
             raise
+    finally:
+        trace.flush()
+
+
+def trace_checkoutput(trace, cmdline, cwd):
+    """
+    Run a program and emit the trace
+    :param cmdline:
+    :param cwd:
+    :return:
+    """
+    try:
+        trace.write(subprocess.check_output(cmdline, cwd=cwd, stderr=subprocess.STDOUT))
+    except subprocess.CalledProcessError as cpe:
+        trace.writeline("Error running {}".format(cmdline))
+        trace.write(cpe.output)
+        raise
 
 
 def run(runner, job, docker):
@@ -177,14 +195,10 @@ def run(runner, job, docker):
         git = job["git_info"]
 
         trace.writeline("Cloning project..")
-        trace.write(subprocess.check_output([
-            "git", "clone", git["repo_url"], build_dir
-        ], cwd=tempdir, stderr=subprocess.STDOUT))
+        trace_checkoutput(trace, ["git", "clone", git["repo_url"], build_dir], cwd=tempdir)
 
         # checkout the ref to build
-        trace.write(subprocess.check_output([
-            "git", "checkout", "-f", get_variable(job, "CI_BUILD_REF")
-        ], cwd=build_dir_abs, stderr=subprocess.STDOUT))
+        trace_checkoutput(trace, ["git", "checkout", "-f", get_variable(job, "CI_BUILD_REF")], cwd=build_dir_abs)
 
         # load the config
         ci_file = os.path.join(build_dir_abs,  get_variable(job, "CI_CONFIG_PATH"))
@@ -204,7 +218,7 @@ def run(runner, job, docker):
                 if var["value"] is None:
                     var["value"] = ""
                 name = var["key"]
-                config["variables"][name] = var["value"]
+                config["variables"][name] = unidecode(var["value"])
 
         jobname = job["job_info"]["name"]
         emulator_job = configloader.load_job(config, jobname)
@@ -237,5 +251,8 @@ def run(runner, job, docker):
 
         trace.writeline("Job complete success={}".format(success))
         return success
+    except Exception as err:
+        trace.writeline("Runner error: {}".format(err))
+
     finally:
         clean(trace, tempdir, docker)
